# Assigned Process Steps

A list of all active process steps that are assigned to the current user. A process step is the running instance of a step with all its relevant information. When a workflow is started a process step is created for every step that gets executed. Therefore, all fields are read-only.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Step:
The step that is currently being executed.

### Attached Model:
The model the workflow is attached to (e.g. Activity). Used to display buttons in the model instances to steer the workflow, set a status field or evaluate conditions.

### Workflow:
The workflow that is currently being executed.

### Started:
Date and time at which this step was started.

### Finished:
Date and time at which this step was finished.

### Group:
The group that this process step is assigned to.

### Permission:
The permission that is needed to be able to view this item.

### Status:
The status that was set on the attached model when this step was executed.

## Search Field:
Typing in the search field allows to filter the process steps by workflow or step name.
